@@ -164,7 +164,8 @@ class dump_documentation implements pts_option_interface
 		$phr = $dom->createElement('hr');
 		$p->appendChild($phr);
 
-		$vendors = array_merge(array_keys(pts_external_dependencies::vendor_alias_list(false)), pts_external_dependencies::vendor_file_parents_list());
+		$exdep_generic_parser = new pts_exdep_generic_parser();
+		$vendors = array_merge($exdep_generic_parser->get_vendor_aliases_formatted(), $exdep_generic_parser->get_vendors_list_formatted());
 		sort($vendors);
 
 		$ul = $dom->createElement('ul');
@@ -248,9 +249,10 @@ class dump_documentation implements pts_option_interface
 				$man_page .= '.SH ' . strtoupper($section) . PHP_EOL;
 
 				sort($contents);
+
 				foreach($contents as &$option)
 				{
-					$man_page .= '.B ' . trim($option[0] . ' ' . implode(' ', $option[1])) . PHP_EOL . $option[2] . PHP_EOL . '.TP' . PHP_EOL;
+					$man_page .= '.B ' . trim($option[0] . ' ' . (!empty($option[1]) && is_array($option[1]) ? implode(' ', $option[1]) : null)) . PHP_EOL . $option[2] . PHP_EOL . '.TP' . PHP_EOL;
 				}
 			}
 			$man_page .= '.SH SEE ALSO' . PHP_EOL . '.B Websites:' . PHP_EOL . '.br' . PHP_EOL . 'http://www.phoronix-test-suite.com/' . PHP_EOL . '.br' . PHP_EOL . 'http://commercial.phoronix-test-suite.com/' . PHP_EOL . '.br' . PHP_EOL . 'http://www.openbenchmarking.org/' . PHP_EOL . '.br' . PHP_EOL . 'http://www.phoronix.com/' . PHP_EOL . '.br' . PHP_EOL . 'http://www.phoronix.com/forums/' . PHP_EOL;
