@@ -23,7 +23,7 @@
 class list_available_suites implements pts_option_interface
 {
 	const doc_section = 'Information';
-	const doc_description = 'This option will list all available test suites that are available from the enabled OpenBenchmarking.org repositories.';
+	const doc_description = 'This option will list all test suites that are available from the enabled OpenBenchmarking.org repositories.';
 
 	public static function command_aliases()
 	{
