@@ -231,6 +231,7 @@ class pts_client
 			'VIDEO_RESOLUTION' => phodevi::read_property('gpu', 'screen-resolution-string'),
 			'VIDEO_CARD' => phodevi::read_name('gpu'),
 			'VIDEO_DRIVER' => phodevi::read_property('system', 'display-driver-string'),
+			'OPENGL_DRIVER' => str_replace('(', '', phodevi::read_property('system', 'opengl-driver')),
 			'OPERATING_SYSTEM' => phodevi::read_property('system', 'operating-system'),
 			'PROCESSOR' => phodevi::read_name('cpu'),
 			'MOTHERBOARD' => phodevi::read_name('motherboard'),
@@ -560,7 +561,6 @@ class pts_client
 		}
 
 		$pso->add_object('environmental_variables_for_modules', pts_module_manager::modules_environmental_variables());
-		$pso->add_object('vendor_alias_list', pts_external_dependencies::vendor_alias_list());
 		$pso->add_object('command_alias_list', pts_documentation::client_commands_aliases());
 
 		$pso->save_to_file(PTS_TEMP_STORAGE);
