@@ -114,9 +114,9 @@ class pts_openbenchmarking_client
 				$system_logs_zip = pts_client::create_temporary_file();
 				pts_compression::zip_archive_create($system_logs_zip, $system_log_dir);
 
-				if(filesize($system_logs_zip) < 1048576)
+				if(filesize($system_logs_zip) < 2097152)
 				{
-					// If it's over 1MB, probably too big
+					// If it's over 2MB, probably too big
 					$system_logs = base64_encode(file_get_contents($system_logs_zip));
 					$system_logs_hash = sha1($system_logs);
 				}
@@ -457,7 +457,7 @@ class pts_openbenchmarking_client
 			$version = substr($test, ($c + 1));
 
 			// TODO: functionalize this and read against types.xsd
-			if(isset($version[4]) && !isset($version[8]) && pts_strings::string_only_contains($version, (pts_strings::CHAR_NUMERIC | pts_strings::CHAR_DECIMAL)))
+			if(isset($version[2]) && !isset($version[8]) && pts_strings::string_only_contains($version, (pts_strings::CHAR_NUMERIC | pts_strings::CHAR_DECIMAL)))
 			{
 				$test = substr($test, 0, $c);
 			}
@@ -509,6 +509,21 @@ class pts_openbenchmarking_client
 				// Looking for a particular test profile version?
 				if($version != null)
 				{
+					if(!in_array($version, $repo_index['tests'][$test]['versions']))
+					{
+						// Grep to see if the version passed was e.g. 1.3 instead of 1.3.3
+						$versions = $repo_index['tests'][$test]['versions'];
+						sort($versions);
+						foreach(array_reverse($versions) as $check_version)
+						{
+							if(strstr($check_version, $version) != false)
+							{
+								$version = $check_version;
+								break;
+							}
+						}
+					}
+
 					if(in_array($version, $repo_index['tests'][$test]['versions']))
 					{
 						pts_openbenchmarking_client::download_test_profile($repo . '/' . $test . '-' . $version);
@@ -530,7 +545,7 @@ class pts_openbenchmarking_client
 							{
 								$version = $v;
 
-								if($i > 0)
+								if($i > 0 && (pts_c::$test_flags ^ pts_c::batch_mode))
 								{
 									// It's not the latest test profile version available
 									trigger_error($repo . '/' . $test . ': The latest test profile version available for upgrade is ' . $available_versions[0] . ' but version ' . $version . ' is the latest currently installed.', E_USER_WARNING);
@@ -551,6 +566,21 @@ class pts_openbenchmarking_client
 				// Looking for a particular test profile version?
 				if($version != null)
 				{
+					if(!in_array($version, $repo_index['suites'][$test]['versions']))
+					{
+						// Grep to see if the version passed was e.g. 1.3 instead of 1.3.3
+						$versions = $repo_index['suites'][$test]['versions'];
+						sort($versions);
+						foreach(array_reverse($versions) as $check_version)
+						{
+							if(strstr($check_version, $version) != false)
+							{
+								$version = $check_version;
+								break;
+							}
+						}
+					}
+
 					if(in_array($version, $repo_index['suites'][$test]['versions']))
 					{
 						pts_openbenchmarking_client::download_test_suite($repo . '/' . $test . '-' . $version);
@@ -632,6 +662,11 @@ class pts_openbenchmarking_client
 	{
 		switch($task)
 		{
+			case 'test_install':
+				list($test_install, $time_elapsed) = $data;
+				$upload_data = array('test_identifier' => $test_install->test_profile->get_identifier(), 'test_version' => $test_install->test_profile->get_test_profile_version(), 'elapsed_time' => $time_elapsed);
+				pts_network::http_upload_via_post(pts_openbenchmarking::openbenchmarking_host() . 'extern/statistics/report-test-install.php', $upload_data);
+				break;
 			case 'test_complete':
 				list($test_result, $time_elapsed) = $data;
 				$upload_data = array('test_identifier' => $test_result->test_profile->get_identifier(), 'test_version' => $test_result->test_profile->get_test_profile_version(), 'elapsed_time' => $time_elapsed);
