@@ -109,6 +109,12 @@ class pts_test_installer
 
 			if($installed)
 			{
+				if(pts_client::do_anonymous_usage_reporting() && $test_install_request->install_time_duration > 0)
+				{
+					// If anonymous usage reporting enabled, report install time to OpenBenchmarking.org
+					pts_openbenchmarking_client::upload_usage_data('test_install', array($test_install_request, $test_install_request->install_time_duration));
+				}
+
 				pts_tests::update_test_install_xml($test_install_request->test_profile, $test_install_request->install_time_duration, true, $compiler_data);
 				array_push($test_profiles, $test_install_request->test_profile);
 			}
@@ -472,7 +478,7 @@ class pts_test_installer
 
 				// Write the main mask for the compiler
 				file_put_contents($main_compiler,
-					'#!/bin/bash' . PHP_EOL . 'COMPILER_OPTIONS="$@"' . PHP_EOL . $env_var_check . PHP_EOL . 'echo $COMPILER_OPTIONS >> ' . $mask_dir . $compiler_type . '-options-' . $compiler_name . PHP_EOL . $compiler_path . ' $COMPILER_OPTIONS' . PHP_EOL);
+					'#!/bin/bash' . PHP_EOL . 'COMPILER_OPTIONS="$@"' . PHP_EOL . $env_var_check . PHP_EOL . 'echo $COMPILER_OPTIONS >> ' . $mask_dir . $compiler_type . '-options-' . $compiler_name . PHP_EOL . $compiler_path . ' "$@"' . PHP_EOL);
 
 				// Make executable
 				chmod($main_compiler, 0755);
@@ -558,7 +564,7 @@ class pts_test_installer
 						unset($compiler_options[$i]);
 					}
 
-					if($option[1] == 'l')
+					if(isset($option[1]) && $option[1] == 'l')
 					{
 						// If you're linking a library it's also useful for other purposes
 						$library = substr($option, 1);
@@ -642,9 +648,9 @@ class pts_test_installer
 				}
 
 				pts_user_io::display_interrupt_message($pre_install_message);
-				$install_time_length_start = time();
+				$install_time_length_start = microtime(true);
 				$install_log = pts_tests::call_test_script($test_install_request->test_profile, 'install', null, $test_install_directory, $test_install_request->special_environment_vars, false);
-				$test_install_request->install_time_duration = time() - $install_time_length_start;
+				$test_install_request->install_time_duration = ceil(microtime(true) - $install_time_length_start);
 				pts_user_io::display_interrupt_message($post_install_message);
 
 				if(!empty($install_log))
