@@ -966,13 +966,14 @@ class pts_test_run_manager
 
 			if(count($tests_missing) == 1)
 			{
-				pts_client::$display->generic_error($tests_missing[0] . ' is not installed.' . PHP_EOL . 'To install, run: phoronix-test-suite install ' . $tests_missing[0]);
+				pts_client::$display->generic_error($tests_missing[0] . ' is not installed.');
+				// PHP_EOL . 'To install, run: phoronix-test-suite install ' . $tests_missing[0]
 			}
 			else
 			{
 				$message = PHP_EOL . PHP_EOL . 'Multiple tests are not installed:' . PHP_EOL . PHP_EOL;
 				$message .= pts_user_io::display_text_list($tests_missing);
-				$message .= PHP_EOL . 'To install, run: phoronix-test-suite install ' . implode(' ', $tests_missing) . PHP_EOL . PHP_EOL;
+				//$message .= PHP_EOL . 'To install, run: phoronix-test-suite install ' . implode(' ', $tests_missing) . PHP_EOL . PHP_EOL;
 				echo $message;
 			}
 
@@ -1447,7 +1448,7 @@ class pts_test_run_manager
 			$report_errors && pts_client::$display->test_run_error('Running on a RAM-based live file-system, cannot run ' . $test_profile);
 			$valid_test_profile = false;
 		}
-		else if(pts_client::read_env('NO_' . strtoupper($test_type) . '_TESTS') ||($skip_tests && (in_array($test_profile, $skip_tests) || in_array($test_type, $skip_tests) || in_array($test_profile->get_identifier(false), $skip_tests) || in_array($run_object->get_identifier_base_name(), $skip_tests))))
+		else if(pts_client::read_env('NO_' . strtoupper($test_type) . '_TESTS') ||($skip_tests && (in_array($test_profile, $skip_tests) || in_array($test_type, $skip_tests) || in_array($test_profile->get_identifier(false), $skip_tests) || in_array($test_profile->get_identifier_base_name(), $skip_tests))))
 		{
 			$report_errors && pts_client::$display->test_run_error('Due to a pre-set environmental variable, skipping ' . $test_profile);
 			$valid_test_profile = false;
