@@ -17,7 +17,7 @@
 	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 	GNU General Public License for more details.
 
-	You should have received a copy of the GNU General Public License$mounts[1]
+	You should have received a copy of the GNU General Public License
 	along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
@@ -59,9 +59,9 @@ class phodevi_disk extends phodevi_device_interface
 		{
 			$mount_point = pts_client::test_install_root_path();
 		}
-		if($mounts == null && is_readable('/proc/mounts'))
+		if($mounts == null && isset(phodevi::$vfs->mounts))
 		{
-			$mounts = file_get_contents('/proc/mounts');
+			$mounts = phodevi::$vfs->mounts;
 		}
 
 		do
@@ -84,7 +84,7 @@ class phodevi_disk extends phodevi_device_interface
 
 			$mounts = explode(' ', $mounts);
 
-			if(isset($mounts[4]) && $mounts[1] == $mount_point && substr($mounts[0], 0, 4) == '/dev')
+			if(isset($mounts[4]) && $mounts[1] == $mount_point && substr($mounts[0], 0, 1) == '/')
 			{
 				// Sort mount options alphabetically so it's easier to look at...
 				$mounts[3] = explode(',', $mounts[3]);
@@ -145,7 +145,7 @@ class phodevi_disk extends phodevi_device_interface
 			{
 				$disk = phodevi_bsd_parser::read_sysctl('dev.ad.' . $i . '.%desc');
 
-				if($disk != false)
+				if($disk != false && strpos($disk, 'DVD') === false && strpos($disk, 'ATAPI') === false)
 				{
 					array_push($disks, $disk);
 				}
@@ -160,7 +160,7 @@ class phodevi_disk extends phodevi_device_interface
 
 				foreach(explode(PHP_EOL, $camcontrol) as $line)
 				{
-					if(substr($line, 0, 1) == '<' && ($model_end = strpos($line, '>')) !== false)
+					if(substr($line, 0, 1) == '<' && ($model_end = strpos($line, '>')) !== false && strpos($line, 'DVD') === false && strpos($line, 'ATAPI') === false)
 					{
 						$disk = self::prepend_disk_vendor(substr($line, 1, ($model_end - 1)));
 						array_push($disks, $disk);
@@ -195,12 +195,18 @@ class phodevi_disk extends phodevi_device_interface
 			$disks_formatted = array();
 			$disks = array();
 
-			foreach(pts_file_io::glob('/sys/block/sd*') as $sdx)
+			foreach(array_merge(pts_file_io::glob('/sys/block/sd*'), pts_file_io::glob('/sys/block/mmcblk*')) as $sdx)
 			{
-				if(is_file($sdx . '/device/model') && is_file($sdx . '/size'))
+				if(strpos($sdx, 'boot') !== false)
+				{
+					// Don't include devices like /sys/block/mmcblk0boot[0,1] as it's repeat of /sys/block/mmcblk0
+					continue;
+				}
+
+				if((is_file($sdx . '/device/name') || is_file($sdx . '/device/model')) && is_file($sdx . '/size'))
 				{
 					$disk_size = pts_file_io::file_get_contents($sdx . '/size');
-					$disk_model = pts_file_io::file_get_contents($sdx . '/device/model');
+					$disk_model = pts_file_io::file_get_contents($sdx .  (is_file($sdx . '/device/model') ? '/device/model' : '/device/name'));
 					$disk_removable = pts_file_io::file_get_contents($sdx . '/removable');
 
 					if($disk_removable == '1')
@@ -245,13 +251,6 @@ class phodevi_disk extends phodevi_device_interface
 			}
 		}
 
-		if(is_file('/sys/class/block/mmcblk0/device/name'))
-		{
-			$disk_name = pts_file_io::file_get_contents('/sys/class/block/mmcblk0/device/name');
-			$disk_size = pts_file_io::file_get_contents('/sys/class/block/mmcblk0/size');
-			array_push($disks, round($disk_size * 512 / 1000000000) . 'GB ' . $disk_name);
-		}
-
 		if(count($disks) == 0)
 		{
 			$root_disk_size = ceil(disk_total_space('/') / 1073741824);
