@@ -90,6 +90,10 @@ class phodevi_gpu extends phodevi_device_interface
 			{
 				$accel_2d = 'UXA';
 			}
+			else if(strpos($xorg_log, 'Gallium3D XA'))
+			{
+				$accel_2d = 'Gallium3D XA';
+			}
 			else if(strpos($xorg_log, 'shadowfb'))
 			{
 				$accel_2d = 'ShadowFB';
@@ -943,6 +947,15 @@ class phodevi_gpu extends phodevi_device_interface
 				}
 			}
 		}
+		else if(phodevi::is_macosx())
+		{
+			$system_profiler_info = implode(' + ', phodevi_osx_parser::read_osx_system_profiler('SPDisplaysDataType', 'ChipsetModel', true));
+
+			if(!empty($system_profiler_info))
+			{
+				$info = $system_profiler_info;
+			}
+		}
 		else if(phodevi::is_nvidia_graphics())
 		{
 			if($info == null)
@@ -1043,10 +1056,6 @@ class phodevi_gpu extends phodevi_device_interface
 	
 		if(empty($info) || strpos($info, 'Mesa ') !== false || strpos($info, 'Gallium ') !== false)
 		{
-			if(phodevi::is_macosx())
-			{
-				$info = phodevi_osx_parser::read_osx_system_profiler('SPDisplaysDataType', 'ChipsetModel');
-			}
 			if(phodevi::is_windows() == false)
 			{
 				$info_pci = phodevi_linux_parser::read_pci('VGA compatible controller', false);
@@ -1055,7 +1064,7 @@ class phodevi_gpu extends phodevi_device_interface
 				{
 					$info = $info_pci;
 
-					if(strpos($info, 'Intel 2nd Generation Core Family') !== false)
+					if(strpos($info, 'Intel 2nd Generation Core Family') !== false || strpos($info, 'Gen Core') !== false)
 					{
 						// Try to come up with a better non-generic string
 						$was_reset = false;
