@@ -42,6 +42,12 @@ class phodevi_memory extends phodevi_device_interface
 		$mem_string = null;
 		$mem_prefix = null;
 
+		$mem_size = false;
+		$mem_speed = false;
+		$mem_type = false;
+		$mem_manufacturer = false;
+		$mem_part = false;
+
 		if(phodevi::is_macosx())
 		{
 			$mem_size = phodevi_osx_parser::read_osx_system_profiler('SPMemoryDataType', 'Size', true, array('Empty'));
@@ -83,12 +89,8 @@ class phodevi_memory extends phodevi_device_interface
 			$mem_size = phodevi_linux_parser::read_dmidecode('memory', 'Memory Device', 'Size', false, array('Not Installed', 'No Module Installed'));
 			$mem_speed = phodevi_linux_parser::read_dmidecode('memory', 'Memory Device', 'Speed', true, 'Unknown');
 			$mem_type = phodevi_linux_parser::read_dmidecode('memory', 'Memory Device', 'Type', true, array('Unknown', 'Other'));
-		}
-		else
-		{
-			$mem_size = false;
-			$mem_speed = false;
-			$mem_type = false;
+			$mem_manufacturer = phodevi_linux_parser::read_dmidecode('memory', 'Memory Device', 'Manufacturer', true, array('Unknown'));
+			$mem_part = phodevi_linux_parser::read_dmidecode('memory', 'Memory Device', 'Part Number', true, array('Unknown'));
 		}
 
 		if(is_array($mem_type))
@@ -124,6 +126,15 @@ class phodevi_memory extends phodevi_device_interface
 				}
 			}
 
+			foreach($mem_size as $i => $mem_stick)
+			{
+				if(!is_numeric(substr($mem_stick, 0, 3)))
+				{
+					// If the memory size isn't at least three digits (basically 128MB+), chances are something is wrong, i.e. reporting flash chip from dmidecode, so get rid of it.
+					unset($mem_size[$i]);
+				}
+			}
+
 			$mem_count = count($mem_size);
 
 			if(!empty($mem_type))
@@ -169,10 +180,28 @@ class phodevi_memory extends phodevi_device_interface
 				{
 					// This makes sure the correct number of RAM modules is reported...
 					// On at least Linux with dmidecode on an AMD Opteron multi-socket setup it's only showing the data for one socket
+
+					if($mem_size[0] < 1024)
+					{
+						$mem_size[0] *= 1024;
+					}
+
 					$mem_count = phodevi::read_property('memory', 'capacity') / $mem_size[0];
 				}
 
-				$mem_string = $mem_count . ' x ' . $mem_size[0] . ' ' . $mem_prefix;
+				$product_string = null;
+
+				if(isset($mem_manufacturer[2]) && ctype_alpha($mem_manufacturer[0]) && stripos($mem_manufacturer, 'manufacturer') === false  && stripos($mem_manufacturer, 'part') === false && stripos($mem_manufacturer, 'module') === false && stripos($mem_manufacturer, 'dimm') === false && isset($mem_manufacturer[2]) && ctype_alpha($mem_manufacturer))
+				{
+					$product_string .= ' ' . $mem_manufacturer;
+				}
+
+				if(isset($mem_part[2]) && stripos($mem_part, 'part') === false && stripos($mem_part, 'module') === false && stripos($mem_part, 'dimm') === false && substr($mem_part, 0, 2) != '0x' && !isset($mem_part[24]) && ctype_alnum($mem_part))
+				{
+					$product_string .= ' ' . $mem_part;
+				}
+
+				$mem_string = $mem_count . ' x ' . $mem_size[0] . ' ' . $mem_prefix . $product_string;
 			}
 		}
 
