@@ -406,7 +406,7 @@ class phodevi_system extends phodevi_device_interface
 			{
 				$modinfo = trim(shell_exec('modinfo -F version vboxguest 2> /dev/null'));
 
-				if($modinfo != null && pts_strings::is_version($modinfo))
+				if($modinfo != null && pts_strings::is_version(str_ireplace(array('_', 'RC', 'beta'), null, $modinfo)))
 				{
 					$virtualized .= ' ' . $modinfo;
 				}
@@ -588,11 +588,13 @@ class phodevi_system extends phodevi_device_interface
 			$compilers['clang'] = $compiler_info;
 		}
 
-		if(pts_client::executable_in_path('llvm-ld'))
+		if(($llvm_ld = pts_client::executable_in_path('llvm-link')) || ($llvm_ld = pts_client::executable_in_path('llvm-ld')))
 		{
 			// LLVM - Low Level Virtual Machine
 			// Reading the version from llvm-ld (the LLVM linker) should be safe as well for finding out version of LLVM in use
-			$info = trim(shell_exec('llvm-ld -version 2> /dev/null'));
+			// As of LLVM 3.2svn, llvm-ld seems to be llvm-link
+
+			$info = trim(shell_exec($llvm_ld . ' -version 2> /dev/null'));
 
 			if(($s = strpos($info, 'version')) != false)
 			{
@@ -1199,7 +1201,7 @@ class phodevi_system extends phodevi_device_interface
 				$display_driver = null;
 
 				// See if the VESA or fbdev driver is in use
-				foreach(array('vesa', 'fbdev') as $drv)
+				foreach(array('vesa', 'fbdev', 'modesetting') as $drv)
 				{
 					$drv_version = phodevi_parser::read_xorg_module_version($drv . '_drv');
 
@@ -1355,7 +1357,7 @@ class phodevi_system extends phodevi_device_interface
 			$cc = null;
 
 			// Clang doesn't report "configured with" but has other useful tid-bits...
-			if(($c = pts_client::executable_in_path('llvm-ld')))
+			if(($c = pts_client::executable_in_path('llvm-ld')) || ($c = pts_client::executable_in_path('llvm-link')))
 			{
 				$llvm_ld = shell_exec($c . ' -version 2>&1');
 				/*
