@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2009 - 2010, Phoronix Media
-	Copyright (C) 2009 - 2010, Michael Larabel
+	Copyright (C) 2009 - 2012, Phoronix Media
+	Copyright (C) 2009 - 2012, Michael Larabel
 	phodevi_bsd_parser.php: General parsing functions specific to BSD
 
 	This program is free software; you can redistribute it and/or modify
@@ -65,7 +65,7 @@ class phodevi_bsd_parser
 			}
 		}
 
-		return $ret;
+		return $ret != 'empty' ? $ret : null;
 	}
 	public static function read_acpiconf($desc)
 	{
