@@ -21,15 +21,7 @@
 	along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
-phodevi::create_vfs();
-
-if(PTS_IS_CLIENT)
-{
-	phodevi::initial_setup();
-}
-
-
-class phodevi
+class phodevi extends phodevi_base
 {
 	public static $vfs = false;
 	private static $device_cache = null;
@@ -63,35 +55,6 @@ class phodevi
 	{
 		return phodevi::read_property($device, 'identifier');
 	}
-	public static function available_hardware_devices()
-	{
-		return array(
-		'Processor' => 'cpu',
-		'Motherboard' => 'motherboard',
-		'Chipset' => 'chipset',
-		'Memory' => 'memory',
-		'Disk' => 'disk',
-		'Graphics' => 'gpu',
-		'Audio' => 'audio',
-		'Monitor' => 'monitor',
-		'Network' => 'network'
-		);
-	}
-	public static function available_software_components()
-	{
-		return array(
-		'OS' => array('system', 'operating-system'),
-		'Kernel' => array('system', 'kernel-string'),
-		'Desktop' => array('system', 'desktop-environment'),
-		'Display Server' => array('system', 'display-server'),
-		'Display Driver' => array('system', 'display-driver-string'),
-		'OpenGL' => array('system', 'opengl-driver'),
-		'Compiler' => array('system', 'compiler'),
-		'File-System' => array('system', 'filesystem'),
-		'Screen Resolution' => array('gpu', 'screen-resolution-string'),
-		'System Layer' => array('system', 'system-layer')
-		);
-	}
 	public static function load_sensors()
 	{
 		foreach(glob(dirname(__FILE__) . '/sensors/*') as $sensor_obj_file)
@@ -541,11 +504,11 @@ class phodevi
 	}
 	public static function is_vendor_string($vendor)
 	{
-		return isset($vendor[2]) && pts_strings::string_only_contains($vendor, (pts_strings::CHAR_LETTER | pts_strings::CHAR_NUMERIC | pts_strings::CHAR_DECIMAL | pts_strings::CHAR_SPACE | pts_strings::CHAR_DASH)) && !pts_strings::has_in_istring($vendor, array('manufacturer', 'vendor', 'unknown', 'generic', 'warning')) && (!isset($vendor[7]) || strpos($vendor, ' ') !== false || pts_strings::times_occurred($vendor, pts_strings::CHAR_NUMERIC) == 0) && pts_strings::string_contains($vendor, pts_strings::CHAR_LETTER) && (isset($vendor[4]) || pts_strings::times_occurred($vendor, pts_strings::CHAR_LETTER) > 1);
+		return isset($vendor[2]) && pts_strings::string_only_contains($vendor, (pts_strings::CHAR_LETTER | pts_strings::CHAR_NUMERIC | pts_strings::CHAR_DECIMAL | pts_strings::CHAR_SPACE | pts_strings::CHAR_DASH)) && !pts_strings::has_in_istring($vendor, array('manufacturer', 'vendor', 'unknown', 'generic', 'warning')) && (!isset($vendor[7]) || strpos($vendor, ' ') !== false || pts_strings::times_occurred($vendor, pts_strings::CHAR_NUMERIC) == 0) && pts_strings::string_contains($vendor, pts_strings::CHAR_LETTER) && (isset($vendor[4]) || pts_strings::times_occurred($vendor, pts_strings::CHAR_LETTER) > 1) && substr($vendor, -1) != '-';
 	}
 	public static function is_product_string($product)
 	{
-		return phodevi::is_vendor_string($product) && !pts_strings::has_in_istring($product, array('VBOX', 'QEMU', 'Virtual', 'Family', '440BX'));
+		return phodevi::is_vendor_string($product) && !pts_strings::has_in_istring($product, array('VBOX', 'QEMU', 'Virtual', 'Family', '440BX', 'VMware', ' Gen', 'Core IGP'));
 	}
 	public static function operating_system()
 	{
@@ -597,4 +560,11 @@ class phodevi
 	}
 }
 
+phodevi::create_vfs();
+
+if(PTS_IS_CLIENT)
+{
+	phodevi::initial_setup();
+}
+
 ?>
