@@ -90,7 +90,9 @@ class pts_render
 			$extra_attributes['compact_to_scalar'] = true;
 		}
 
-		if($result_file->is_multi_way_comparison() || isset($extra_attributes['compact_to_scalar']) || $result_file->is_results_tracker())
+		// XXX: removed || $result_file->is_results_tracker() from below and should be added
+		// Removing the command fixes cases like: 1210053-BY-MYRESULTS43
+		if($result_file->is_multi_way_comparison() || isset($extra_attributes['compact_to_scalar']))
 		{
 			if((isset($extra_attributes['compact_to_scalar']) || (false && $result_file->is_multi_way_comparison())) && in_array($result_object->test_profile->get_display_format(), array('LINE_GRAPH', 'FILLED_LINE_GRAPH')))
 			{
@@ -487,7 +489,7 @@ class pts_render
 					$key = array_pop($key);
 				}
 
-				if(isset($diff[$key]))
+				if(isset($key) && isset($diff[$key]))
 				{
 					$unique_compiler_data = array();
 					foreach($json as $identifier => &$data)
@@ -498,6 +500,11 @@ class pts_render
 						}
 					}
 
+					if(!isset($unique_compiler_data[1]))
+					{
+						break;
+					}
+
 					if(($c0 = count($unique_compiler_data[0])) < ($c1 = count($unique_compiler_data[1])))
 					{
 						for($i = 0; $i < ($c1 - $c0); $i++)
@@ -1003,7 +1010,8 @@ class pts_render
 
 			// Around Firefox 3.0 era is best
 			// Firefox 2.0 mostly works except text might not show...
-			if($gecko_date < 200702)
+			// With Firefox 17.0 it's now Gecko/17.0 rather than a date...
+			if(substr($gecko_date, 0, 3) == '200' && $gecko_date < 200702)
 			{
 				$selected_renderer = 'PNG';
 			}
