@@ -130,6 +130,12 @@ class pts_result_file
 	{
 		return count($this->get_unique_test_titles());
 	}
+	public function get_contained_tests_hash()
+	{
+		$result_object_hashes = $this->get_result_object_hashes();
+		sort($result_object_hashes);
+		return sha1(implode(',', $result_object_hashes));
+	}
 	public function get_result_object_hashes()
 	{
 		$object_hashes = array();
