@@ -122,7 +122,13 @@ class pts_test_result
 			{
 				foreach($keys as $k)
 				{
-					if($this->test_result_buffer->buffer_items[$k]->get_result_identifier() == $normalize_against)
+					if($is_multi_way && strpos($this->test_result_buffer->buffer_items[$k]->get_result_identifier(), ': ' . $normalize_against) !== false)
+					{
+						// This allows it to just normalize against part of the string
+						$divide_value = $this->test_result_buffer->buffer_items[$k]->get_result_value();
+						break;
+					}
+					else if($this->test_result_buffer->buffer_items[$k]->get_result_identifier() == $normalize_against)
 					{
 						$divide_value = $this->test_result_buffer->buffer_items[$k]->get_result_value();
 						break;
