@@ -21,9 +21,9 @@
 	along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
-define('PTS_VERSION', '4.0.0');
-define('PTS_CORE_VERSION', 4000);
-define('PTS_CODENAME', 'SULDAL');
+define('PTS_VERSION', '4.2.0');
+define('PTS_CORE_VERSION', 4200);
+define('PTS_CODENAME', 'RANDABERG');
 define('PTS_IS_CLIENT', (defined('PTS_MODE') && PTS_MODE == 'CLIENT'));
 define('PTS_IS_DEV_BUILD', (substr(PTS_VERSION, -2, 1) == 'm'));
 
@@ -107,6 +107,7 @@ function pts_version_codenames()
 		'3.8' => 'Bygland',
 		'4.0' => 'Suldal',
 		'4.2' => 'Randaberg',
+		'4.4' => 'Forsand'
 		);
 }
 
